.. _readme:
.. include:: ../README.rst

.. jsonschema:: ../src/amix/amix.json#/definitions/amix

.. jsonschema:: ../src/amix/amix.json#/definitions/clip

.. jsonschema:: ../src/amix/amix.json#/definitions/filter

.. jsonschema:: ../src/amix/amix.json#/definitions/part

.. jsonschema:: ../src/amix/amix.json#/definitions/segment

.. jsonschema:: ../src/amix/amix.json#/definitions/reference
